import { Candle } from "../types/types_ohlc";
import { FunctionRegistry } from "./feature_dsl_parser";
export interface StrategySchema {
    name: string;
    entry_long?: string;
    entry_short?: string;
    exit_long?: string;
    exit_short?: string;
    stop_loss_expr?: string;
    target_expr?: string;
    risk_per_trade?: number;
    capital: number;
    cooldown_period?: number;
    allow_reentry?: boolean;
    breakeven_trigger_expr?: string;
    trailing_trigger_expr?: string;
    trailing_offset_expr?: string;
    transaction_charges?: number;
}
export interface Trade {
    entry_index: number;
    exit_index: number;
    entry_time: string;
    exit_time: string;
    entry_price: number;
    exit_price: number;
    position_size: number;
    side: "long" | "short";
    pnl: number;
    pnl_percent: number;
    reason: "tp" | "sl" | "exit_condition";
    stop_price?: number;
    take_profit_price?: number;
    trailing_triggered?: boolean;
    breakeven_triggered?: boolean;
}
export interface StrategyState {
    in_position: boolean;
    entry_index: number | null;
    entry_time: string | null;
    entry_price: number | null;
    position_size: number;
    stop_price: number | null;
    take_profit_price: number | null;
    breakeven_triggered: boolean;
    trailing_stop_active: boolean;
    cooldown_remaining: number;
    side: "long" | "short" | null;
    last_exit_price?: number;
    last_exit_index?: number;
    last_exit_reason?: "sl" | "tp" | "exit_condition";
}
export declare class StrategyRunner {
    private candles;
    private strategy;
    private function_registry;
    private trades;
    private capital;
    private state;
    constructor(candles: Candle[], strategy: StrategySchema, function_registry: FunctionRegistry);
    run(): Trade[];
    private try_entry;
    private try_exit;
    get_report(): {
        strategy: string;
        capital_start: number;
        capital_end: number;
        total_trades: number;
        win_rate: number;
        avg_pnl: number;
        avg_pnl_percent: number;
        avg_win: number;
        avg_loss: number;
        avg_hold: number;
        total_profit: number;
        trades: Trade[];
    };
}
